@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 """Implements the Atomic-VAEP framework."""
+from . import features, formula, labels
 from .base import AtomicVAEP
 
-__all__ = ['AtomicVAEP']
+__all__ = ['AtomicVAEP', 'features', 'labels', 'formula']
